;-----------------------------------------------------------------------------
; frank the fruit fly
;-----------------------------------------------------------------------------
# pmio.asm is the include file that defines hardware register names 
# the file is included in the tutorial zip file

	.include "pm_init.s"
	.include "pmio.asm"

	pm_header "fruit_flyfun", IRQ_KEY_POWER | IRQ_MUSIC | IRQ_PRC_COPY, 0
	
	.include "pmrom_music.s"

	.ram	sfx_select	1
	.ram	bgm_select	1
	.ram	prc_tick	1

	; Power button, shutdown PM
irq_key_power:
	cint CINT_SHUTDOWN

	; Act as VSync counter
irq_prc_copy:
	push hl
	mov hl, prc_tick
	inc [hl]
	pop hl
	rirq IRQ_PRC_COPY

;-----------------------------------------------------------------------------
; Memory addresses
;-----------------------------------------------------------------------------
ticker:
.db 0	
frankdir:
.db 0
frankx:
.db 0
franky:
.db 0
	
;-----------------------------------------------------------------------------
; Interrupt numbers
;-----------------------------------------------------------------------------
	.equ	IntSuspend		0x21
	.equ	IntShutdown		0x24

;-----------------------------------------------------------------------------
; Title screen Setup
;-----------------------------------------------------------------------------
main:  
	xor a,a
	mov [ticker],a
	
	; Interrupts
	enable_irqs IRQ_KEY_POWER | IRQ_PRC_COPY	

	mov ba, MAP_BASE
	mov hl, $00FF
	call pmmusic_init
	
	; Enable interrupt
	enable_mirq	

    movw	sp,REG_BASE
    movw	nn,REG_BASE

	mov b, 0
	mov a, [bgm_select]
	shl a
	shl a
	shl a
	shl a
	mov hl, bgm_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playbgm

    movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
	mov		x1, titlescreenpic
	movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

	mov		x1, player
    movw	[REG_BASE+REG_LCD_SPRITEMEM], x1
	
    movb	[nn+REG_EVENT2P],INT2P_KEYPAD
    movb	[nn+REG_EVENT2S],INT2S_KEY_POWER

    ; Activate all interrupts
    mov		flags, 0

    movb	[nn+REG_LCD_CNT0], LCD0_RENDER|LCD0_TILEBG|LCD0_MAP12x16|LCD0_SPRITES
    movb	[nn+REG_LCD_CNT1], LCD1_ENABLE|LCD1_REFRESH1

	mov nn,OAM
	
	mov a,50
	mov [frankx],a		
	
	mov		[frankx],a
	
	mov [nn+0],a			

	mov a,52
	mov [franky],a		
	
	mov		[franky],a
	
	mov [nn+1],a

	mov [nn+2],0
	mov [nn+3],OAM_ENABLE

	mov nn,REG_BASE
	
;-----------------------------------------------------------------------------
; Title screen
;-----------------------------------------------------------------------------
title_screen:
		mov		a, [ticker]
		add		a, 1
		mov		[ticker], a
	
		mov		a, [ticker] 
		cmp		a, 3
		jg		move_frank
		
		jmp title_screen
	
move_frank:
		mov		a, [OAM+0]
		add		a, 1
		mov		[OAM+0], a

		mov a,0
		mov [ticker],a		
	
		jmp title_screen
;-----------------------------------------------------------------------------
; Files it uses
;-----------------------------------------------------------------------------
	.align 16
	
bgm_list:
	.dd music_test
	
bgm_list_last:	.db 7

	PMMUSIC_ALIGN

music_data_start:
	.include "music_title.asm"	

	pm_align_tiles
titlescreenpic:
	.incbin franktitle.bin	

	pm_align_spr
player:
	.incbin franksprites.bin